import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as ByTagAPI from 'cloudflare/resources/rulesets/versions/by-tag';
import * as RulesAPI from 'cloudflare/resources/rulesets/rules';
import * as RulesetsAPI from 'cloudflare/resources/rulesets/rulesets';
export declare class ByTag extends APIResource {
    /**
     * Fetches the rules of a managed account ruleset version for a given tag.
     */
    get(rulesetId: string, rulesetVersion: string, ruleTag: string, params: ByTagGetParams, options?: Core.RequestOptions): Core.APIPromise<ByTagGetResponse>;
}
/**
 * A ruleset object.
 */
export interface ByTagGetResponse {
    /**
     * The unique ID of the ruleset.
     */
    id: string;
    /**
     * The kind of the ruleset.
     */
    kind: RulesetsAPI.Kind;
    /**
     * The timestamp of when the ruleset was last modified.
     */
    last_updated: string;
    /**
     * The human-readable name of the ruleset.
     */
    name: string;
    /**
     * The phase of the ruleset.
     */
    phase: RulesetsAPI.Phase;
    /**
     * The list of rules in the ruleset.
     */
    rules: Array<RulesAPI.BlockRule | RulesAPI.ChallengeRule | RulesAPI.CompressResponseRule | RulesAPI.ExecuteRule | RulesAPI.JSChallengeRule | RulesAPI.LogRule | RulesAPI.ManagedChallengeRule | RulesAPI.RedirectRule | RulesAPI.RewriteRule | RulesAPI.RouteRule | RulesAPI.ScoreRule | RulesAPI.ServeErrorRule | RulesAPI.SetConfigRule | RulesAPI.SkipRule | RulesAPI.SetCacheSettingsRule>;
    /**
     * The version of the ruleset.
     */
    version: string;
    /**
     * An informative description of the ruleset.
     */
    description?: string;
}
export interface ByTagGetParams {
    /**
     * The unique ID of the account.
     */
    account_id: string;
}
export declare namespace ByTag {
    export import ByTagGetResponse = ByTagAPI.ByTagGetResponse;
    export import ByTagGetParams = ByTagAPI.ByTagGetParams;
}
//# sourceMappingURL=by-tag.d.ts.map